@@ -550,7 +550,7 @@ public class DSAdmin extends AbstractServerObject
 			if ( (i > 0) && (i < (id.length()-1)) )
 				id = id.substring( i + 1 );
 			_framework.setTitle( _serverInfo.getHost() + " - " +
-								 resource.getString("dialog", "configtitle") +
+								 DSUtil._skinResource.getString("dialog", "configtitle") +
 								 " - " + id );
 		}
 	}
@@ -751,7 +751,7 @@ public class DSAdmin extends AbstractServerObject
 		_pagefeeder = new DSPageFeeder( this, _info, _serverInfo );
 		_framework = new DSFramework( this, _pagefeeder );
 		_framework.setHelpDirectory( DSUtil.HELP_DIRECTORY );
-		_framework.getAccessibleContext().setAccessibleDescription(resource.getString("dsAdmin",
+		_framework.getAccessibleContext().setAccessibleDescription(DSUtil._skinResource.getString("dsAdmin",
                                                                                               "framework-description"));
 		_pagefeeder.setFrame( _framework );
 		_pagefeeder.addPreferencesTab(new DSPreferencesTab());
