@@ -273,6 +273,11 @@ public class EncryptionPanel extends BlankPanel
 
 			// Warn the user he needs to restart the server
 			DSUtil.showInformationDialog(frame, "requires-restart", (String)null);
+			
+			// If they are enabling encryption, warn them to trust the CA chain too
+			if (_configData.sslServerOn) {
+				DSUtil.showInformationDialog(frame, "warn-ca-chain-trust", (String)null, _section);
+			}
 
 			/* Warn the user: port below 1024 require root install on unix */
 			if (_configData.sslServerOn && !DSUtil.isNT(consoleInfo)) {
@@ -685,6 +690,7 @@ class EncryptionConfigData {
 	// This value is used when the nsssl3ciphers attribute is not
 	// present in the directory. It must match the default of slapd.
 	static final String CIPHER_PREFS = "-rsa_null_md5," +
+	                                   "-rsa_null_sha," +
 	                                   "+rsa_rc4_128_md5," +
 	                                   "+rsa_rc4_40_md5," +
 									   "+rsa_rc2_40_md5," +
@@ -696,13 +702,16 @@ class EncryptionConfigData {
 									   "+fortezza_rc4_128_sha," +
 									   "+fortezza_null," +
 									   "+tls_rsa_export1024_with_rc4_56_sha," +
-	                                   "+tls_rsa_export1024_with_des_cbc_sha";
+	                                   "+tls_rsa_export1024_with_des_cbc_sha," +
+	                                   "+tls_rsa_aes_128_sha," +
+	                                   "+tls_rsa_aes_256_sha";
 	
 	// Cipher list to build the SSL3 tab in the cipher dialog
 	static final String CIPHER_SSL3_OFF = "-rsa_null_md5," +
-	                                      "-rsa_rc4_128_md5," +
-	                                      "-rsa_rc4_40_md5," +
+	                                      "-rsa_null_sha," +
 										  "-rsa_rc2_40_md5," +
+	                                      "-rsa_rc4_40_md5," +
+	                                      "-rsa_rc4_128_md5," +
 										  "-rsa_des_sha," +
 										  "-rsa_fips_des_sha," +
 	                                      "-rsa_3des_sha," +
@@ -713,7 +722,9 @@ class EncryptionConfigData {
 
 	// Cipher list to build the TLS tab in the cipher dialog
 	static final String CIPHER_TLS_OFF =  "-tls_rsa_export1024_with_rc4_56_sha," +
-	                                      "-tls_rsa_export1024_with_des_cbc_sha";
+	                                      "-tls_rsa_export1024_with_des_cbc_sha," +
+	                                      "-tls_rsa_aes_128_sha," +
+	                                      "-tls_rsa_aes_256_sha";
 										  
 	// Reads the directory and initializes this instance
 	public void readFromDirectory(LDAPConnection ldc, LDAPConnection sieldc, String sieDn)
